@@ -45,7 +45,6 @@ def projection():
     help="WARNING: this command will be DEPRECATED, please use 'projection update' command.",
 )
 @click.option("--filename", type=click.Path())
-@click.option("--logs_location", default=PROD_API_URL, type=click.STRING)
 @click.option("--api_url", default=PROD_API_URL, type=click.STRING)
 @click.option("--api_key", type=click.STRING)
 @click.option(
@@ -53,10 +52,12 @@ def projection():
     is_flag=True,
     help="Enable dry run to test resulting Docker image before uploading to Gantry",
 )
-def register(filename, logs_location, api_url, api_key=None, dry_run=False):
+def register(filename, api_url, api_key=None, dry_run=False):
+    click.secho(
+        "WARNING: This command is DEPRECATED, please use the 'projection update' command instead.",
+        fg="red",
+    )
     init_kwargs = {}
-    if logs_location:
-        init_kwargs["logs_location"] = logs_location
     if api_key:
         init_kwargs["api_key"] = api_key
     gantry.init(**init_kwargs)
@@ -70,7 +71,7 @@ def register(filename, logs_location, api_url, api_key=None, dry_run=False):
         api_url = urlunparse(parsed_url)
 
     api_client = APIClient(origin=api_url, api_key=api_key)
-    print(f"Registering custom projection to url {api_url} using logs location at {logs_location}")
+    print(f"Registering custom projection to url {api_url}")
     if not filename.endswith(".yaml"):
         raise click.ClickException(
             "The supplied file to gantry projection register must be a .yaml file that "
