@@ -9,11 +9,11 @@ class BatchType(str, Enum):
 
 class UploadFileType(str, Enum):
     CSV_WITH_HEADERS = "CSV_WITH_HEADERS"
-    EVENTS_BYTES = "EVENTS_BYTES"
+    EVENTS = "EVENTS"
 
 
 class Delimiter(Enum):
     COMMA = ","
 
 
-CHUNK_SIZE = 10 * 1024 * 1024  # File upload chunk size 10 MB
+CHUNK_SIZE = 100 * 1024 * 1024  # File upload chunk size 100 MB
