@@ -9,7 +9,6 @@ from typing import Callable, Collection, Dict, Iterator, List, Optional
 
 from gantry.api_client import APIClient
 from gantry.logger.consumer import BatchConsumer
-from gantry.query.core.utils import check_response
 from gantry.serializers import EventEncoder
 
 logger = logging.getLogger(__name__)
@@ -119,8 +118,7 @@ class APILogStore(BaseLogStore):
             # Cannot use /healthz/* endpoints as those will be answered by nginx
             # need to use /.
             # See https://linear.app/gantry/issue/ENG-2978/revisit-ping-in-sdk
-            response = self._api_client.request("GET", "/api/ping")
-            check_response(response)
+            self._api_client.request("GET", "/api/ping", raise_for_status=True)
             return True
         except Exception as e:
             logger.error(f"Error during ping: {e}")
@@ -132,8 +130,7 @@ class APILogStore(BaseLogStore):
         the provided API Key.
         """
         try:
-            response = self._api_client.request("GET", "/api/v1/auth-ping")
-            check_response(response)
+            self._api_client.request("GET", "/api/v1/auth-ping", raise_for_status=True)
             return True
         except Exception as e:
             logger.error(f"Error during api key check: {e}")
