@@ -17,7 +17,6 @@ from gantry.exceptions import GantryException, QueryError
 from gantry.query.core.constants import MAX_SIZE_CACHE_B, MAX_TTL_CACHE_SECS
 from gantry.query.core.queryframe import GantryQueryFrame, QueryInfo
 from gantry.query.core.utils import (
-    check_response,
     get_application_node_id,
     get_application_views,
     get_last_application_version,
@@ -33,7 +32,10 @@ def _raw_query_cached_request(
     api_client: APIClient, dumped_json_data: str, resource: str = "aggregate"
 ):
     return api_client.request(
-        "POST", f"/api/v1/{resource}/query", json=json.loads(dumped_json_data)
+        "POST",
+        f"/api/v1/{resource}/query",
+        json=json.loads(dumped_json_data),
+        raise_for_status=True,
     )
 
 
@@ -753,11 +755,12 @@ class GantrySeries(GantryQueryFrame):
             }
         }
         resource = "aggregate" if num_points == 1 else "time_series"
-        response = _raw_query_cached_request(
-            self.api_client, json.dumps(data, default=lambda x: x.isoformat()), resource=resource
-        )
         try:
-            check_response(response)
+            response = _raw_query_cached_request(
+                self.api_client,
+                json.dumps(data, default=lambda x: x.isoformat()),
+                resource=resource,
+            )
             data = response["data"]["query"]
 
             if num_points == 1:
@@ -766,9 +769,7 @@ class GantrySeries(GantryQueryFrame):
                 return pd.DataFrame(data["points"])
 
         except GantryException as e:
-            raise GantryException(
-                "Aggregation query [" + attribute + "] failed on API with this error: " + str(e)
-            )
+            raise GantryException("Aggregation query [" + attribute + "] failed: " + str(e))
 
     def _describe(self) -> dict:
         c = self.count()
