@@ -10,7 +10,7 @@ except ImportError:
 import pandas as pd
 
 from gantry.query.core.dataframe import GantrySeries
-from gantry.query.core.utils import check_response, same_size
+from gantry.query.core.utils import same_size
 
 
 def _prepare_pandas_dataframe(stat, results, dropna) -> pd.DataFrame:
@@ -138,8 +138,9 @@ class GantryMetric(object):
             },
         }
 
-        response = self._api_client.request("POST", "/api/v1/time_series/query", json=data)
-        check_response(response)
+        response = self._api_client.request(
+            "POST", "/api/v1/time_series/query", json=data, raise_for_status=True
+        )
         return response["data"]["query_label"].get("points", [])
 
     @categorical
