@@ -1080,7 +1080,7 @@ def test_log_feedback(mock_uuid, feedbacks, random_error, timestamps, sort, tags
         mock_uuid.side_effect = RuntimeError
     else:
         mock_uuid.return_value = "ABCD1234"
-    cli_obj.log_feedback(
+    rv = cli_obj.log_feedback(
         application="foobar",
         feedback_ids=[{"A": 100}, {"B": 200}],
         feedbacks=feedbacks,
@@ -1090,6 +1090,7 @@ def test_log_feedback(mock_uuid, feedbacks, random_error, timestamps, sort, tags
         as_batch=False,
         tags=tags,
     )
+    assert rv is None
     events = [
         {
             "batch_id": None,
@@ -1407,7 +1408,7 @@ def test_log_predictions(mock_uuid, inputs, outputs, random_error, timestamps, s
         mock_uuid.side_effect = RuntimeError
     else:
         mock_uuid.return_value = "ABCD1234"
-    cli_obj.log_predictions(
+    rv = cli_obj.log_predictions(
         application="foobar",
         inputs=inputs,
         outputs=outputs,
@@ -1419,6 +1420,7 @@ def test_log_predictions(mock_uuid, inputs, outputs, random_error, timestamps, s
         as_batch=False,
         tags=tags,
     )
+    assert rv is None
 
     events = [
         {
@@ -1719,11 +1721,13 @@ def test_log_predictions_as_batch(
         )
 
         if method == "log_predictions":
-            init_gantry_with_api.log_predictions(
+            rv = init_gantry_with_api.log_predictions(
                 "simple_test", inputs, outputs, version, sort_on_timestamp=sort, as_batch=True
             )
+
+            assert rv == "hello_123"
         elif method == "log_records_prediction":
-            init_gantry_with_api.log_records(
+            rv = init_gantry_with_api.log_records(
                 "simple_test",
                 version,
                 inputs=inputs,
@@ -1731,8 +1735,10 @@ def test_log_predictions_as_batch(
                 sort_on_timestamp=sort,
                 as_batch=True,
             )
+
+            assert rv == "hello_123"
         elif method == "log_records":
-            init_gantry_with_api.log_records(
+            rv = init_gantry_with_api.log_records(
                 "simple_test",
                 version,
                 inputs=inputs,
@@ -1741,6 +1747,8 @@ def test_log_predictions_as_batch(
                 sort_on_timestamp=sort,
                 as_batch=True,
             )
+
+            assert rv == "hello_123"
         mock_batch_success.assert_called_once_with(
             "hello_123", "simple_test", init_gantry_with_api.get_client().log_store
         )
@@ -1782,7 +1790,7 @@ def test_log_feedback_as_batch(
         )
 
         if method == "log_feedback":
-            init_gantry_with_api.log_feedback(
+            rv = init_gantry_with_api.log_feedback(
                 application="simple_test",
                 feedback_ids=feedbacks,
                 feedbacks=feedbacks,
@@ -1790,8 +1798,10 @@ def test_log_feedback_as_batch(
                 sort_on_timestamp=sort,
                 as_batch=True,
             )
+
+            assert rv == "hello_123"
         elif method == "log_records_feedback":
-            init_gantry_with_api.log_records(
+            rv = init_gantry_with_api.log_records(
                 "simple_test",
                 version,
                 feedback_ids=feedbacks,
@@ -1799,6 +1809,8 @@ def test_log_feedback_as_batch(
                 sort_on_timestamp=sort,
                 as_batch=True,
             )
+
+            assert rv == "hello_123"
         mock_batch_success.assert_called_once_with(
             "hello_123", "simple_test", init_gantry_with_api.get_client().log_store
         )
@@ -2141,11 +2153,38 @@ def test__upload_data_as_batch(
     )
 
 
+@mock.patch("gantry.logger.client.Gantry._log_predictions_and_feedbacks")
+def test_log_records_preds_and_feedback_series_coerced(
+    mock_preds_and_feedback,
+    cli_obj,
+):
+    expected_inputs = pd.Series([200, 201])
+    expected_outputs = pd.Series([300, 301])
+    expected_feedbacks = pd.Series([100, 101])
+    application = "test_app"
+
+    cli_obj.log_records(
+        application=application,
+        inputs=expected_inputs,
+        outputs=expected_outputs,
+        feedbacks=expected_feedbacks,
+    )
+
+    downstream_kwargs = mock_preds_and_feedback.call_args.kwargs
+    actual_inputs = downstream_kwargs["inputs"]
+    actual_outputs = downstream_kwargs["outputs"]
+    actual_feedbacks = downstream_kwargs["feedbacks"]
+    pd.testing.assert_frame_equal(actual_inputs, expected_inputs.to_frame())
+    pd.testing.assert_frame_equal(actual_outputs, expected_outputs.to_frame())
+    pd.testing.assert_frame_equal(actual_feedbacks, expected_feedbacks.to_frame())
+
+
 @pytest.mark.parametrize(
     "test_feedbacks",
     [
         [{"A": 200}, {"A": 201}],
         pd.DataFrame.from_dict({"A": [200, 201]}),
+        pd.Series(name="A", data=[200, 201]),
     ],
 )
 @pytest.mark.parametrize(
@@ -2153,6 +2192,7 @@ def test__upload_data_as_batch(
     [
         [{"B": 300}, {"B": 301}],
         pd.DataFrame.from_dict({"B": [300, 301]}),
+        pd.Series(name="B", data=[300, 301]),
     ],
 )
 @pytest.mark.parametrize(
@@ -2160,6 +2200,7 @@ def test__upload_data_as_batch(
     [
         [{"A": 100}, {"A": 101}],
         pd.DataFrame.from_dict({"A": [100, 101]}),
+        pd.Series(name="A", data=[100, 101]),
     ],
 )
 @pytest.mark.parametrize("version", [None, 10, "1.2.3"])
@@ -2176,7 +2217,7 @@ def test_log_records_preds_and_feedback(
     test_feedbacks,
     cli_obj,
 ):
-    cli_obj.log_records(
+    rv = cli_obj.log_records(
         application="foobar",
         version=version,
         inputs=test_inputs,
@@ -2186,6 +2227,7 @@ def test_log_records_preds_and_feedback(
         timestamps=None,
         sort_on_timestamp=True,
     )
+    assert rv is None
 
     mock_preds_and_feedback.assert_called_once()
     mock_preds.assert_not_called()
@@ -2197,6 +2239,7 @@ def test_log_records_preds_and_feedback(
     [
         [{"A": 200}, {"A": 201}],
         pd.DataFrame.from_dict({"A": [200, 201]}),
+        pd.Series(name="A", data=[200, 201]),
     ],
 )
 @pytest.mark.parametrize(
@@ -2204,6 +2247,7 @@ def test_log_records_preds_and_feedback(
     [
         [{"B": 300}, {"B": 301}],
         pd.DataFrame.from_dict({"B": [300, 301]}),
+        pd.Series(name="B", data=[300, 301]),
     ],
 )
 @pytest.mark.parametrize(
@@ -2211,6 +2255,7 @@ def test_log_records_preds_and_feedback(
     [
         [{"A": 100}, {"A": 101}],
         pd.DataFrame.from_dict({"A": [100, 101]}),
+        pd.Series(name="A", data=[100, 101]),
     ],
 )
 @pytest.mark.parametrize("version", [None, 10, "1.2.3"])
@@ -2240,6 +2285,7 @@ def test_log_records_preds_and_feedback_0_5(version, test_inputs, test_outputs,
     [
         [{"A": 200}, {"A": 201}],
         pd.DataFrame.from_dict({"A": [200, 201]}),
+        pd.Series(name="A", data=[200, 201]),
     ],
 )
 @pytest.mark.parametrize(
@@ -2247,6 +2293,7 @@ def test_log_records_preds_and_feedback_0_5(version, test_inputs, test_outputs,
     [
         [{"B": 300}, {"B": 301}],
         pd.DataFrame.from_dict({"B": [300, 301]}),
+        pd.Series(name="B", data=[300, 301]),
     ],
 )
 @pytest.mark.parametrize(
@@ -2254,6 +2301,7 @@ def test_log_records_preds_and_feedback_0_5(version, test_inputs, test_outputs,
     [
         [{"A": 100}, {"A": 101}],
         pd.DataFrame.from_dict({"A": [100, 101]}),
+        pd.Series(name="A", data=[100, 101]),
     ],
 )
 @pytest.mark.parametrize("version", [None, 10, "1.2.3"])
@@ -2285,6 +2333,7 @@ def test_log_records_preds_and_feedback_0_5_none(
     [
         [{"A": 200}, {"A": 201}],
         pd.DataFrame.from_dict({"A": [200, 201]}),
+        pd.Series(name="A", data=[200, 201]),
     ],
 )
 @pytest.mark.parametrize(
@@ -2292,6 +2341,7 @@ def test_log_records_preds_and_feedback_0_5_none(
     [
         [{"B": 300}, {"B": 301}],
         pd.DataFrame.from_dict({"B": [300, 301]}),
+        pd.Series(name="B", data=[300, 301]),
     ],
 )
 @pytest.mark.parametrize(
@@ -2299,6 +2349,7 @@ def test_log_records_preds_and_feedback_0_5_none(
     [
         [{"A": 100}, {"A": 101}],
         pd.DataFrame.from_dict({"A": [100, 101]}),
+        pd.Series(name="A", data=[100, 101]),
     ],
 )
 @pytest.mark.parametrize("version", [None, 10, "1.2.3"])
@@ -2328,6 +2379,7 @@ def test_log_records_preds_and_feedback_0_0(version, test_inputs, test_outputs,
     [
         [{"B": 300}, {"B": 301}],
         pd.DataFrame.from_dict({"B": [300, 301]}),
+        pd.Series(name="B", data=[300, 301]),
     ],
 )
 @pytest.mark.parametrize(
@@ -2335,6 +2387,7 @@ def test_log_records_preds_and_feedback_0_0(version, test_inputs, test_outputs,
     [
         [{"A": 100}, {"A": 101}],
         pd.DataFrame.from_dict({"A": [100, 101]}),
+        pd.Series(name="A", data=[100, 101]),
     ],
 )
 @pytest.mark.parametrize("version", [None, 10, "1.2.3"])
@@ -2344,7 +2397,7 @@ def test_log_records_preds_and_feedback_0_0(version, test_inputs, test_outputs,
 def test_log_records_preds_only(
     mock_feedback, mock_preds, mock_preds_and_feedback, version, test_inputs, test_outputs, cli_obj
 ):
-    cli_obj.log_records(
+    rv = cli_obj.log_records(
         application="foobar",
         version=version,
         inputs=test_inputs,
@@ -2354,6 +2407,7 @@ def test_log_records_preds_only(
         timestamps=None,
         sort_on_timestamp=True,
     )
+    assert rv is None
 
     mock_preds_and_feedback.assert_not_called()
     mock_preds.assert_called_once()
@@ -2365,6 +2419,7 @@ def test_log_records_preds_only(
     [
         [{"A": 200}, {"A": 201}],
         pd.DataFrame.from_dict({"A": [200, 201]}),
+        pd.Series(name="A", data=[200, 201]),
     ],
 )
 @pytest.mark.parametrize("version", [None, 10, "1.2.3"])
@@ -2374,7 +2429,7 @@ def test_log_records_preds_only(
 def test_log_records_feedback_only(
     mock_feedback, mock_preds, mock_preds_and_feedback, version, test_feedbacks, cli_obj
 ):
-    cli_obj.log_records(
+    rv = cli_obj.log_records(
         application="foobar",
         version=version,
         inputs=None,
@@ -2384,6 +2439,7 @@ def test_log_records_feedback_only(
         timestamps=None,
         sort_on_timestamp=True,
     )
+    assert rv is None
 
     mock_preds_and_feedback.assert_not_called()
     mock_preds.assert_not_called()
@@ -2392,15 +2448,15 @@ def test_log_records_feedback_only(
 
 @pytest.mark.parametrize(
     "test_feedbacks",
-    [None, pd.DataFrame(), []],
+    [None, pd.DataFrame(), [], pd.Series()],
 )
 @pytest.mark.parametrize(
     "test_outputs",
-    [None, pd.DataFrame(), []],
+    [None, pd.DataFrame(), [], pd.Series()],
 )
 @pytest.mark.parametrize(
     "test_inputs",
-    [None, pd.DataFrame(), []],
+    [None, pd.DataFrame(), [], pd.Series()],
 )
 @pytest.mark.parametrize("version", [None, 10, "1.2.3"])
 @mock.patch("gantry.logger.client.Gantry._log_predictions_and_feedbacks")
@@ -2416,7 +2472,7 @@ def test_log_records_no_data(
     test_feedbacks,
     cli_obj,
 ):
-    cli_obj.log_records(
+    rv = cli_obj.log_records(
         application="foobar",
         version=version,
         inputs=test_inputs,
@@ -2426,6 +2482,7 @@ def test_log_records_no_data(
         timestamps=None,
         sort_on_timestamp=True,
     )
+    assert rv is None
 
     mock_preds_and_feedback.assert_not_called()
     mock_preds.assert_not_called()
@@ -2434,7 +2491,7 @@ def test_log_records_no_data(
 
 @pytest.mark.parametrize(
     "test_feedbacks",
-    [None, pd.DataFrame(), [{"A": 3}, {"A": 3}]],
+    [None, pd.DataFrame(), [{"A": 3}, {"A": 3}], pd.Series()],
 )
 @mock.patch("gantry.logger.client.Gantry._log_predictions_and_feedbacks")
 @mock.patch("gantry.logger.client.Gantry.log_predictions")
@@ -2446,7 +2503,7 @@ def test_log_records_incomplete_preds(
     test_feedbacks,
     cli_obj,
 ):
-    cli_obj.log_records(
+    rv = cli_obj.log_records(
         application="foobar",
         version="2.0.1",
         inputs=[],
@@ -2456,6 +2513,7 @@ def test_log_records_incomplete_preds(
         timestamps=None,
         sort_on_timestamp=True,
     )
+    assert rv is None
 
     mock_preds_and_feedback.assert_not_called()
     mock_preds.assert_not_called()
